@@ -4,10 +4,10 @@
 # @author       Michael McLennan <mmclennan@purdue.edu>
 # @author       Derrick Kearney <dsk@purdue.edu>
 # @author       Nicholas J. Kisseberth <nkissebe@purdue.edu>
-# @copyright    Copyright (c) 2004-2012 HUBzero Foundation, LLC.
+# @copyright    Copyright (c) 2004-2013 HUBzero Foundation, LLC.
 # @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 #
-# Copyright (c) 2004-2012 HUBzero Foundation, LLC.
+# Copyright (c) 2004-2013 HUBzero Foundation, LLC.
 #
 # This file is part of: The HUBzero(R) Platform for Scientific Collaboration
 #
@@ -208,7 +208,7 @@ proc filexfer::accept {cid addr port} {
     fconfigure $cid -buffering line -translation binary
 
     # we accept clients from any where, but only let them
-    # speak FILEXFER protocol when they come from localhost
+    # speak FILEXFER protocol when they come from 127.0.0.1 [localhost]
     variable address
     set address($cid) $addr
     filexfer::log "accepted client $cid on $addr"
@@ -1081,9 +1081,9 @@ proc filexfer::request_EXPORT {cid arglist cookie proto} {
     variable fxcookie
     variable address
 
-    # clients must come from localhost and share a secret
+    # clients must come from 127.0.0.1 [localhost] and share a secret
     if {![string equal $address($cid) "127.0.0.1"]} {
-        puts $cid [list ERROR "unauthorized access -- must come from localhost"]
+        puts $cid [list ERROR "unauthorized access -- must come from 127.0.0.1 [localhost]"]
         flush $cid
         shutdown $cid
         return
@@ -1193,12 +1193,12 @@ proc filexfer::request_IMPORT {cid template cookie} {
     variable downloads
     variable downloadInfo
 
-    # clients must come from localhost and share a secret
+    # clients must come from 127.0.0.1 [localhost] and share a secret
     variable fxcookie
     variable address
 
     if {![string equal $address($cid) "127.0.0.1"]} {
-        puts $cid [list ERROR "unauthorized access -- must come from localhost"]
+        puts $cid [list ERROR "unauthorized access -- must come from 127.0.0.1 [localhost]"]
         flush $cid
         shutdown $cid
         return
@@ -1289,12 +1289,12 @@ proc filexfer::request_IMPORT {cid template cookie} {
 # coming to them queued up on various requests.
 # ----------------------------------------------------------------------
 proc filexfer::request_BYE {cid cookie} {
-    # clients must come from localhost and share a secret
+    # clients must come from 127.0.0.1 [localhost] and share a secret
     variable fxcookie
     variable address
 
     if {![string equal $address($cid) "127.0.0.1"]} {
-        puts $cid [list ERROR "unauthorized access -- must come from localhost"]
+        puts $cid [list ERROR "unauthorized access -- must come from 127.0.0.1 [localhost]"]
         flush $cid
         shutdown $cid
         return
